@@ -391,6 +391,8 @@ class State:
             "type": "Element",
             "namespace": "",
             "required": True,
+            "white_space": "collapse",
+            "pattern": r"\d+ \d+",
         },
     )
     wall_time: str = field(
@@ -399,6 +401,8 @@ class State:
             "type": "Element",
             "namespace": "",
             "required": True,
+            "white_space": "collapse",
+            "pattern": r"\d+ \d+",
         },
     )
     real_time: str = field(
@@ -407,6 +411,8 @@ class State:
             "type": "Element",
             "namespace": "",
             "required": True,
+            "white_space": "collapse",
+            "pattern": r"\d+ \d+",
         },
     )
     iterations: int = field(
